@@ -15,7 +15,7 @@ i2c = busio.I2C(board.SCL, board.SDA)
 # Initialize the MPL3115A2.
 sensor = adafruit_mpl3115a2.MPL3115A2(i2c)
 # Alternatively you can specify a different I2C address for the device:
-#sensor = adafruit_mpl3115a2.MPL3115A2(i2c, address=0x10)
+# sensor = adafruit_mpl3115a2.MPL3115A2(i2c, address=0x10)
 
 # You can configure the pressure at sealevel to get better altitude estimates.
 # This value has to be looked up from your local weather forecast or meteorlogical
@@ -27,9 +27,9 @@ sensor.sealevel_pressure = 102250
 # Main loop to read the sensor values and print them every second.
 while True:
     pressure = sensor.pressure
-    print('Pressure: {0:0.3f} pascals'.format(pressure))
+    print("Pressure: {0:0.3f} pascals".format(pressure))
     altitude = sensor.altitude
-    print('Altitude: {0:0.3f} meters'.format(altitude))
+    print("Altitude: {0:0.3f} meters".format(altitude))
     temperature = sensor.temperature
-    print('Temperature: {0:0.3f} degrees Celsius'.format(temperature))
+    print("Temperature: {0:0.3f} degrees Celsius".format(temperature))
     time.sleep(1.0)
